@@ -830,7 +830,7 @@ tvterm_put_otherCS_char(TVterm *p, u_char ch)
 	/* output bytes */
 	s = sizeof(p->otherCS->outbuf) - outbuflen;
 
-	if (strcmp(p->otherCS->tocode, "UTF-8") == 0) {
+	if (strcmp(p->otherCS->tocode, "UTF-8") == 0 && p->altCs == FALSE) {
 		p->ucs2ch = 0;
 		for (i = 0; i < s; i++) {
 			p->ucs2ch <<= 8;
